@@ -13,5 +13,5 @@ nearby_devices = bluetooth.discover_devices(lookup_names = True)
 
 print "found %d devices" % len(nearby_devices)
 
-for name, addr in nearby_devices:
+for addr, name in nearby_devices:
     print "  %s - %s" % (addr, name)
